==> Sah-PSchemas-Perl-0.009.tar.gz: Sah-PSchemas-Perl-0.009/lib/Sah/PSchemas/Perl.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package Sah::PSchemas::Perl;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-09-29'; # DATE
our $DIST = 'Sah-PSchemas-Perl'; # DIST
our $VERSION = '0.009'; # VERSION

1;
# ABSTRACT: Parameterized schemas related to Perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::PSchemas::Perl - Parameterized schemas related to Perl

=head1 VERSION

This document describes version 0.009 of Sah::PSchemas::Perl (from Perl distribution Sah-PSchemas-Perl), released on 2021-09-29.

=head1 DESCRIPTION

B<EXPERIMENTAL.>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-PSchemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-PSchemas-Perl>.

=head1 SEE ALSO

C<Sah::Schemas::Perl>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
beyond that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-PSchemas-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> Sah-PSchemas-Perl-0.010.tar.gz: Sah-PSchemas-Perl-0.010/lib/Sah/PSchemas/Perl.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package Sah::PSchemas::Perl;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-09-25'; # DATE
our $DIST = 'Sah-PSchemas-Perl'; # DIST
our $VERSION = '0.010'; # VERSION

1;
# ABSTRACT: Parameterized schemas related to Perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::PSchemas::Perl - Parameterized schemas related to Perl

=head1 VERSION

This document describes version 0.010 of Sah::PSchemas::Perl (from Perl distribution Sah-PSchemas-Perl), released on 2022-09-25.

=head1 DESCRIPTION

B<EXPERIMENTAL.>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-PSchemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-PSchemas-Perl>.

=head1 SEE ALSO

C<Sah::Schemas::Perl>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-PSchemas-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
